import { useEffect, useRef, useState } from "react";
import { Animated, View } from "react-native";
const AccordionView = ({ visible, children }) => {
    const [opened, setOpened] = useState(visible);
    const [bodySectionHeight, setBodySectionHeight] = useState(0);
    const animatedHeightValue = useRef(new Animated.Value(0)).current;
    const bodyHeight = animatedHeightValue.interpolate({
        inputRange: [0, 1],
        outputRange: [0, bodySectionHeight]
    });
    useEffect(() => {
        toggleList(visible);
    }, [visible]);
    const toggleList = (show) => {
        if (!show) {
            Animated.timing(animatedHeightValue, {
                duration: 300,
                toValue: 0,
                useNativeDriver: false
            }).start(() => {
                setOpened(false);
            });
        }
        else {
            setOpened(true);
            Animated.timing(animatedHeightValue, {
                duration: 300,
                toValue: 1,
                useNativeDriver: false
            });
        }
    };
    return (opened ?
        <Animated.View style={{ height: bodyHeight }}>
        <View onLayout={(ev) => setBodySectionHeight(ev.nativeEvent.layout.height)} style={{ position: "absolute", bottom: 0 }}>
          {children}
        </View>
      </Animated.View>
        : null);
};
export { AccordionView };
//# sourceMappingURL=AccordionView.js.map